# coding: utf-8

"""
    zrok

    zrok client access  # noqa: E501

    OpenAPI spec version: 0.3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Principal(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'email': 'str',
        'token': 'str',
        'limitless': 'bool',
        'admin': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'email': 'email',
        'token': 'token',
        'limitless': 'limitless',
        'admin': 'admin'
    }

    def __init__(self, id=None, email=None, token=None, limitless=None, admin=None):  # noqa: E501
        """Principal - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._email = None
        self._token = None
        self._limitless = None
        self._admin = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if email is not None:
            self.email = email
        if token is not None:
            self.token = token
        if limitless is not None:
            self.limitless = limitless
        if admin is not None:
            self.admin = admin

    @property
    def id(self):
        """Gets the id of this Principal.  # noqa: E501


        :return: The id of this Principal.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Principal.


        :param id: The id of this Principal.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def email(self):
        """Gets the email of this Principal.  # noqa: E501


        :return: The email of this Principal.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Principal.


        :param email: The email of this Principal.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def token(self):
        """Gets the token of this Principal.  # noqa: E501


        :return: The token of this Principal.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this Principal.


        :param token: The token of this Principal.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def limitless(self):
        """Gets the limitless of this Principal.  # noqa: E501


        :return: The limitless of this Principal.  # noqa: E501
        :rtype: bool
        """
        return self._limitless

    @limitless.setter
    def limitless(self, limitless):
        """Sets the limitless of this Principal.


        :param limitless: The limitless of this Principal.  # noqa: E501
        :type: bool
        """

        self._limitless = limitless

    @property
    def admin(self):
        """Gets the admin of this Principal.  # noqa: E501


        :return: The admin of this Principal.  # noqa: E501
        :rtype: bool
        """
        return self._admin

    @admin.setter
    def admin(self, admin):
        """Sets the admin of this Principal.


        :param admin: The admin of this Principal.  # noqa: E501
        :type: bool
        """

        self._admin = admin

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Principal, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Principal):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
